@@ -581,44 +581,38 @@ TerminalNewMode(f)
     if (f == -1) {
 	onoff = 0;
     } else {
+#ifdef BIN_TERM
+	/* f = f & ~MODE_OUTBIN | MODE_INBIN; */
+	f |= MODE_INBIN; 
+	    /* 
+		 * this should enable umlauts and other 8-bit chars
+		 * (adapt them to your local needs)
+		 */
+#endif
 #ifndef	USE_TERMIO
-#  ifndef BIN_TERM
 	if (f & MODE_OUTBIN)
-#  endif
 		lmode |= LLITOUT;
-#  ifndef BIN_TERM
 	else
 		lmode &= ~LLITOUT;
-#  endif
 
-#  ifndef BIN_TERM
 	if (f & MODE_INBIN)
-#  endif
 		lmode |= LPASS8;
-#  ifndef BIN_TERM
 	else
 		lmode &= ~LPASS8;
-#  endif
 #else
-#  ifndef BIN_TERM
 	if (f & MODE_INBIN)
-#  endif
 		tmp_tc.c_iflag &= ~ISTRIP;
-#  ifndef BIN_TERM
 	else
 		tmp_tc.c_iflag |= ISTRIP;
 	if (f & MODE_OUTBIN) {
-#  endif
 		tmp_tc.c_cflag &= ~(CSIZE|PARENB);
 		tmp_tc.c_cflag |= CS8;
 		tmp_tc.c_oflag &= ~OPOST;
-#  ifndef BIN_TERM
 	} else {
 		tmp_tc.c_cflag &= ~(CSIZE|PARENB);
 		tmp_tc.c_cflag |= old_tc.c_cflag & (CSIZE|PARENB);
 		tmp_tc.c_oflag |= OPOST;
 	}
-#  endif
 #endif
 	onoff = 1;
     }
