@@ -102,7 +102,11 @@ extern struct sysv sysv;
 #include <sys/resource.h>
 #include <sys/proc.h>
 #endif
+#ifdef LINUX
+#include <linux/tty.h>
+#else
 #include <sys/tty.h>
+#endif
 #ifdef	t_erase
 #undef	t_erase
 #undef	t_kill
